@@ -1270,7 +1270,8 @@ class TestAgent(object):
         refilled on the reloaded page, provided that the reloaded page has
         exactly the same fields present in the same order.
         """
-        self.logger and self.logger.debug("Reload", self.request.request_path)
+        self.logger and self.logger.debug("Reload: %s",
+                                          self.request.request_path)
         env = self.request.environ.copy()
         del env['pesto.request']
         env['wsgi.input'].seek(0)
